package com.lanren.huhu.partner.service.impl;

import com.lanren.huhu.partner.service.IMailService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.mail.javamail.JavaMailSenderImpl;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Service;

import javax.mail.MessagingException;
import javax.mail.internet.MimeMessage;
import java.io.File;
import java.util.Properties;

/**
 * @author chen
 * @title: IMailServiceImpl
 * @projectName partner
 * @package com.lanren.huhu.partner.service.impl
 * @date 2019-09-26 19:59
 */
@Service
public class IMailServiceImpl implements IMailService {
    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    /**
     * Spring Boot 提供了一个发送邮件的简单抽象，使用的是下面这个接口，这里直接注入即可使用
     */
    @Autowired
    private JavaMailSenderImpl mailSender;

    /**
     * 配置
     */
    @Value("${spring.mail.host}")
    private String host;
    @Value("${spring.mail.username}")
    private String username;
    @Value("${spring.mail.password}")
    private String password;
    @Value("${spring.mail.port}")
    private String port;
    @Value("${spring.mail.from}")
    private String from;

    @Override
    public void sendMail(String subject, String text, File attachment, String[] tos) throws MessagingException {
        MimeMessage mailMessage = configMailMessage();
        configMessageHelper(mailMessage, subject, text, attachment, tos, new String[]{});
        mailSender.send(mailMessage);
    }

    @Override
    public void sendMailWithCc(String subject, String text, File attachment, String[] tos, String[] cc) throws MessagingException {
        MimeMessage mailMessage = configMailMessage();
        MimeMessageHelper mimeMessageHelper = configMessageHelper(mailMessage, subject, text, attachment, tos, new String[]{});
        mimeMessageHelper.setCc(cc);
        mailSender.send(mailMessage);
    }

    private MimeMessage configMailMessage() {
        mailSender.setHost(host);
        mailSender.setPort(Integer.parseInt(port));
        mailSender.setUsername(username);
        mailSender.setPassword(password);
        mailSender.setDefaultEncoding("UTF-8");

        Properties javaMailProperties = new Properties();
        javaMailProperties.setProperty("mail.smtp.auth", "true");
        javaMailProperties.setProperty("mail.smtp.timeout", "25000");
        mailSender.setJavaMailProperties(javaMailProperties);

        return mailSender.createMimeMessage();
    }

    private MimeMessageHelper configMessageHelper(MimeMessage mailMessage, String subject, String text, File attachment, String[] tos, String[] cc)
            throws MessagingException {
        MimeMessageHelper mimeMessageHelper = new MimeMessageHelper(mailMessage, true, "UTF-8");
        mimeMessageHelper.setFrom(from);
        mimeMessageHelper.setSubject(subject);
        mimeMessageHelper.setText(text, true);
        if (attachment != null) {
            mimeMessageHelper.addAttachment(attachment.getName(), attachment);
        }
        mimeMessageHelper.setTo(tos);
        return mimeMessageHelper;
    }

}
